pub struct BlockProducerClient(/* private fields */);Methods from Deref<Target = ApiClient<InterceptedService<Channel, Interceptor>>>
Sourcepub async fn status(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<BlockProducerStatus>, Status>
pub async fn status( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<BlockProducerStatus>, Status>
Returns the status info.
Sourcepub async fn submit_proven_transaction(
&mut self,
request: impl IntoRequest<ProvenTransaction>,
) -> Result<Response<BlockNumber>, Status>
pub async fn submit_proven_transaction( &mut self, request: impl IntoRequest<ProvenTransaction>, ) -> Result<Response<BlockNumber>, Status>
Submits proven transaction to the Miden network. Returns the node’s current block height.
Sourcepub async fn submit_proven_batch(
&mut self,
request: impl IntoRequest<TransactionBatch>,
) -> Result<Response<BlockNumber>, Status>
pub async fn submit_proven_batch( &mut self, request: impl IntoRequest<TransactionBatch>, ) -> Result<Response<BlockNumber>, Status>
Submits a batch of transactions to the Miden network.
All transactions in this batch will be considered atomic, and be committed together or not all.
Returns the node’s current block height.
Sourcepub async fn mempool_subscription(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<Streaming<MempoolEvent>>, Status>
pub async fn mempool_subscription( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<Streaming<MempoolEvent>>, Status>
Subscribe to mempool events.
The event stream will contain all events after the current chain tip. This includes all currently inflight events that have not yet been committed to the chain.
Currently only a single active subscription is supported. Subscription requests will cancel the active subscription, if any.