pub struct Builder<State> { /* private fields */ }Expand description
A type-safe builder that forces the caller to make an explicit decision for each configuration item (TLS, timeout, metadata version, metadata genesis) before connecting.
This builder replaces the previous defaulted builder. Callers must explicitly choose TLS, timeout, and metadata options before connecting.
Usage example:
let url = Url::parse("https://rpc.example.com:8080")?;
let client: RpcClient = Builder::new(url)
.with_tls()? // or `.without_tls()`
.with_timeout(Duration::from_secs(5)) // or `.without_timeout()`
.with_metadata_version("1.0".into()) // or `.without_metadata_version()`
.without_metadata_genesis() // or `.with_metadata_genesis(genesis)`
.with_otel_context_injection() // or `.without_otel_context_injection()`
.connect::<RpcClient>()
.await?;Implementations
Sourceimpl Builder<WantsTls>
impl Builder<WantsTls>
Sourcepub fn new(url: Url) -> Builder<WantsTls>
pub fn new(url: Url) -> Builder<WantsTls>
Create a new strict builder from a gRPC endpoint URL such as
http://localhost:8080 or https://api.example.com:443.
Sourcepub fn without_tls(self) -> Builder<WantsTimeout>
pub fn without_tls(self) -> Builder<WantsTimeout>
Explicitly disable TLS.
Sourcepub fn with_tls(self) -> Result<Builder<WantsTimeout>>
pub fn with_tls(self) -> Result<Builder<WantsTimeout>>
Explicitly enable TLS.
Sourceimpl Builder<WantsTimeout>
impl Builder<WantsTimeout>
Sourcepub fn without_timeout(self) -> Builder<WantsVersion>
pub fn without_timeout(self) -> Builder<WantsVersion>
Explicitly disable request timeout.
Sourcepub fn with_timeout(self, duration: Duration) -> Builder<WantsVersion>
pub fn with_timeout(self, duration: Duration) -> Builder<WantsVersion>
Explicitly configure a request timeout.
Sourceimpl Builder<WantsVersion>
impl Builder<WantsVersion>
Sourcepub fn without_metadata_version(self) -> Builder<WantsGenesis>
pub fn without_metadata_version(self) -> Builder<WantsGenesis>
Do not include version in request metadata.
Sourcepub fn with_metadata_version(self, version: String) -> Builder<WantsGenesis>
pub fn with_metadata_version(self, version: String) -> Builder<WantsGenesis>
Include a specific version string in request metadata.
Sourceimpl Builder<WantsGenesis>
impl Builder<WantsGenesis>
Sourcepub fn without_metadata_genesis(self) -> Builder<WantsOTel>
pub fn without_metadata_genesis(self) -> Builder<WantsOTel>
Do not include genesis commitment in request metadata.
Sourcepub fn with_metadata_genesis(self, genesis: String) -> Builder<WantsOTel>
pub fn with_metadata_genesis(self, genesis: String) -> Builder<WantsOTel>
Include a specific genesis commitment string in request metadata.
Sourceimpl Builder<WantsOTel>
impl Builder<WantsOTel>
Sourcepub fn with_otel_context_injection(self) -> Builder<WantsConnection>
pub fn with_otel_context_injection(self) -> Builder<WantsConnection>
Enables OpenTelemetry context propagation via gRPC.
This is used to by OpenTelemetry to connect traces across network boundaries. The server on the other end must be configured to receive and use the injected trace context.
Sourcepub fn without_otel_context_injection(self) -> Builder<WantsConnection>
pub fn without_otel_context_injection(self) -> Builder<WantsConnection>
Disables OpenTelemetry context propagation. This should be disabled when interfacing with external third party gRPC servers.
Sourceimpl Builder<WantsConnection>
impl Builder<WantsConnection>
Sourcepub async fn connect<T>(self) -> Result<T>where
T: GrpcClient,
pub async fn connect<T>(self) -> Result<T>where
T: GrpcClient,
Establish an eager connection and return a fully configured client.
Sourcepub fn connect_lazy<T>(self) -> Twhere
T: GrpcClient,
pub fn connect_lazy<T>(self) -> Twhere
T: GrpcClient,
Establish a lazy connection and return a client that will connect on first use.