pub struct StoreBlockProducerClient(/* private fields */);Methods from Deref<Target = BlockProducerClient<InterceptedService<Channel, Interceptor>>>
Sourcepub async fn apply_block(
&mut self,
request: impl IntoRequest<ApplyBlockRequest>,
) -> Result<Response<()>, Status>
pub async fn apply_block( &mut self, request: impl IntoRequest<ApplyBlockRequest>, ) -> Result<Response<()>, Status>
Applies changes of a new block to the DB and in-memory data structures.
Sourcepub async fn get_block_header_by_number(
&mut self,
request: impl IntoRequest<BlockHeaderByNumberRequest>,
) -> Result<Response<BlockHeaderByNumberResponse>, Status>
pub async fn get_block_header_by_number( &mut self, request: impl IntoRequest<BlockHeaderByNumberRequest>, ) -> Result<Response<BlockHeaderByNumberResponse>, Status>
Retrieves block header by given block number. Optionally, it also returns the MMR path and current chain length to authenticate the block’s inclusion.
Sourcepub async fn get_block_inputs(
&mut self,
request: impl IntoRequest<BlockInputsRequest>,
) -> Result<Response<BlockInputs>, Status>
pub async fn get_block_inputs( &mut self, request: impl IntoRequest<BlockInputsRequest>, ) -> Result<Response<BlockInputs>, Status>
Returns data required to prove the next block.
Sourcepub async fn get_batch_inputs(
&mut self,
request: impl IntoRequest<BatchInputsRequest>,
) -> Result<Response<BatchInputs>, Status>
pub async fn get_batch_inputs( &mut self, request: impl IntoRequest<BatchInputsRequest>, ) -> Result<Response<BatchInputs>, Status>
Returns the inputs for a transaction batch.
Sourcepub async fn get_transaction_inputs(
&mut self,
request: impl IntoRequest<TransactionInputsRequest>,
) -> Result<Response<TransactionInputs>, Status>
pub async fn get_transaction_inputs( &mut self, request: impl IntoRequest<TransactionInputsRequest>, ) -> Result<Response<TransactionInputs>, Status>
Returns data required to validate a new transaction.