Module decode

Module decode 

Re-exports

pub use crate::errors::ConversionResultExt;

Structs

GrpcStructDecoder
Zero-cost struct decoder that captures the parent proto message type.

Traits

DecodeBytesExt
Extension trait on Deserializable types to deserialize from bytes and wrap errors as ConversionError.
GrpcDecodeExt
Extension trait on prost::Message types to create a GrpcStructDecoder with the parent type inferred from the value.

Functions

convert_digests_to_words
Converts a collection of proto primitives to Words, returning a specific error type if conversion fails
read_account_id
read_account_ids
Reads account IDs from a request, returning a specific error type if conversion fails
read_block_range
Reads a block range from a request, returning a specific error type if the field is missing
read_root
Reads and converts a root field from a request to Word, returning a specific error type if conversion fails