read_root

Function read_root 

pub fn read_root<E>(
    root: Option<Digest>,
    entity: &'static str,
) -> Result<Word, E>
Reads and converts a root field from a request to Word, returning a specific error type if conversion fails