GrpcDecodeExt

Trait GrpcDecodeExt 

pub trait GrpcDecodeExt: Message + Sized {
    // Provided method
    fn decoder(&self) -> GrpcStructDecoder<Self> { ... }
}
Extension trait on prost::Message types to create a GrpcStructDecoder with the parent type inferred from the value.

Provided Methods

fn decoder(&self) -> GrpcStructDecoder<Self>

Create a decoder that uses Self as the parent message type for error reporting.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors