pub enum AccountVaultDetails {
LimitExceeded,
Assets(Vec<Asset>),
}Expand description
Account vault details
When an account contains a large number of assets (>
AccountVaultDetails::MAX_RETURN_ENTRIES), including all assets in a single RPC response
creates performance issues. In such cases, the LimitExceeded variant indicates to the client
to use the SyncAccountVault endpoint instead.
Variants
LimitExceeded
The vault has too many assets to return inline. Clients must use SyncAccountVault endpoint
instead.
Assets(Vec<Asset>)
The assets in the vault (up to MAX_RETURN_ENTRIES).
Implementations
Sourceimpl AccountVaultDetails
impl AccountVaultDetails
Sourcepub const MAX_RETURN_ENTRIES: usize = 1000
pub const MAX_RETURN_ENTRIES: usize = 1000
Maximum number of vault entries that can be returned in a single response. Accounts with
more assets will have LimitExceeded variant.
pub fn empty() -> Self
Sourcepub fn from_assets(assets: Vec<Asset>) -> Self
pub fn from_assets(assets: Vec<Asset>) -> Self
Creates AccountVaultDetails from a list of assets.