pub struct DecodedIsInvitationCodeValidRequest {
pub invitation_code: String,
}Expand description
Decoded invitation check fields. The invitation code remains unvalidated.
Fields
invitation_code: StringTrait Implementations
Sourceimpl TryFrom<IsInvitationCodeValidRequest> for DecodedIsInvitationCodeValidRequest
impl TryFrom<IsInvitationCodeValidRequest> for DecodedIsInvitationCodeValidRequest
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourceimpl Verify for DecodedIsInvitationCodeValidRequest
Returns the raw invitation code. The handler validates the code because an empty code is
accepted when allowlist enforcement is disabled.
impl Verify for DecodedIsInvitationCodeValidRequest
Returns the raw invitation code. The handler validates the code because an empty code is accepted when allowlist enforcement is disabled.