Module note

Module note 

Structs

SingleTargetNetworkNote
A newtype that wraps around notes targeting a single network account.

Enums

NetworkNote
An enum that wraps around notes used in a network mode.
NetworkNoteError