pub struct AccountWitness {
pub account_id: Option<AccountId>,
pub witness_id: Option<AccountId>,
pub commitment: Option<Digest>,
pub path: Option<SparseMerklePath>,
}Expand description
An account witness.
Fields
account_id: Option<AccountId>Account ID for which this proof is requested.
witness_id: Option<AccountId>The account ID within the proof, which may be different from the above account ID. This can happen when the requested account ID’s prefix matches the prefix of an existing account ID in the tree. Then the witness will prove inclusion of this witness ID in the tree.
commitment: Option<Digest>The state commitment whose inclusion the witness proves.
path: Option<SparseMerklePath>The merkle path of the state commitment in the account tree.