pub struct SignedBlock {
pub header: Option<BlockHeader>,
pub body: Option<BlockBody>,
pub signature: Option<BlockSignature>,
}Expand description
Represents a signed block.
Fields
header: Option<BlockHeader>body: Option<BlockBody>signature: Option<BlockSignature>Trait Implementations
Sourceimpl Clone for SignedBlock
impl Clone for SignedBlock
Sourcefn clone(&self) -> SignedBlock
fn clone(&self) -> SignedBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedBlock
impl Debug for SignedBlock
Sourceimpl Default for SignedBlock
impl Default for SignedBlock
Sourceimpl From<&SignedBlock> for SignedBlock
impl From<&SignedBlock> for SignedBlock
Sourcefn from(block: &SignedBlock) -> Self
fn from(block: &SignedBlock) -> Self
Converts to this type from the input type.
Sourceimpl From<SignedBlock> for SignedBlock
impl From<SignedBlock> for SignedBlock
Sourcefn from(block: SignedBlock) -> Self
fn from(block: SignedBlock) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SignedBlock
impl Hash for SignedBlock
Sourceimpl Message for SignedBlock
impl Message for SignedBlock
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SignedBlock
impl PartialEq for SignedBlock
Sourceimpl TryFrom<&SignedBlock> for SignedBlock
impl TryFrom<&SignedBlock> for SignedBlock
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<SignedBlock> for SignedBlock
impl TryFrom<SignedBlock> for SignedBlock
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
impl Eq for SignedBlock
impl StructuralPartialEq for SignedBlock