pub struct SyncTransactionsResponse {
pub pagination_info: Option<PaginationInfo>,
pub transactions: Vec<TransactionRecord>,
}Fields
pagination_info: Option<PaginationInfo>transactions: Vec<TransactionRecord>Trait Implementations
Sourceimpl Clone for SyncTransactionsResponse
impl Clone for SyncTransactionsResponse
Sourceimpl Debug for SyncTransactionsResponse
impl Debug for SyncTransactionsResponse
Sourceimpl DecodeMessage for SyncTransactionsResponse
impl DecodeMessage for SyncTransactionsResponse
type Decoded = DecodedSyncTransactionsResponse
fn decode_fields(self) -> Result<Self::Decoded, ConversionError>
Sourceimpl Default for SyncTransactionsResponse
impl Default for SyncTransactionsResponse
Sourceimpl Message for SyncTransactionsResponse
impl Message for SyncTransactionsResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SyncTransactionsResponse
impl PartialEq for SyncTransactionsResponse
impl StructuralPartialEq for SyncTransactionsResponse
Sourceimpl TryFrom<SyncTransactionsResponse> for DecodedSyncTransactionsResponse
impl TryFrom<SyncTransactionsResponse> for DecodedSyncTransactionsResponse
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.