pub struct DecodedAuthenticatedTransactionBatch {
pub proposed_batch: <ProposedBatch as DecodeMessage>::Decoded,
pub auth_inputs: RepeatedField<<AuthInputs as DecodeMessage>::Decoded>,
pub batch_proof: <ProvenBatch as DecodeMessage>::Decoded,
}Expand description
Decoded fields of AuthenticatedTransactionBatch. Domain invariants have not been verified.
Fields
proposed_batch: <ProposedBatch as DecodeMessage>::Decodedauth_inputs: RepeatedField<<AuthInputs as DecodeMessage>::Decoded>batch_proof: <ProvenBatch as DecodeMessage>::DecodedTrait Implementations
Sourceimpl TryFrom<AuthenticatedTransactionBatch> for DecodedAuthenticatedTransactionBatch
impl TryFrom<AuthenticatedTransactionBatch> for DecodedAuthenticatedTransactionBatch
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourceimpl VerifyWith<u32> for DecodedAuthenticatedTransactionBatch
impl VerifyWith<u32> for DecodedAuthenticatedTransactionBatch
Sourcefn verify_with(self, security_level: u32) -> Result<Self::Verified, Self::Error>
fn verify_with(self, security_level: u32) -> Result<Self::Verified, Self::Error>
Verify transaction proofs at the supplied security level and decode store inputs. Check the batch proof against the proposed batch. The caller must trust the sender’s store authentication data. The mempool checks dependencies, conflicts, and expiration.
type Verified = (ProvenBatch, ProposedBatch, Vec<TransactionInputs>)
type Error = ConversionError