pub struct DecodedSignBlockRequest {
pub batches: RepeatedField<<ProvenBatch as DecodeMessage>::Decoded>,
pub block_inputs: <BlockInputs as DecodeMessage>::Decoded,
pub timestamp: u32,
pub next_validator_config: <ValidatorConfig as DecodeMessage>::Decoded,
pub next_protocol_config: OptionalField<<NextProtocolConfig as DecodeMessage>::Decoded>,
pub protocol_config: OptionalField<<ProtocolConfig as DecodeMessage>::Decoded>,
}Expand description
Decoded fields of SignBlockRequest. Domain invariants have not been verified.
Fields
batches: RepeatedField<<ProvenBatch as DecodeMessage>::Decoded>block_inputs: <BlockInputs as DecodeMessage>::Decodedtimestamp: u32next_validator_config: <ValidatorConfig as DecodeMessage>::Decodednext_protocol_config: OptionalField<<NextProtocolConfig as DecodeMessage>::Decoded>protocol_config: OptionalField<<ProtocolConfig as DecodeMessage>::Decoded>Trait Implementations
Sourceimpl BuildUnchecked for DecodedSignBlockRequest
impl BuildUnchecked for DecodedSignBlockRequest
Sourcefn build_unchecked(self) -> Result<Self::Output, Self::Error>
fn build_unchecked(self) -> Result<Self::Output, Self::Error>
Build the proposal and check any supplied protocol configuration against its header. The caller must verify the parent and batch proofs and contents before signing.
type Output = SignBlockRequest
type Error = ConversionError
Sourceimpl Debug for DecodedSignBlockRequest
impl Debug for DecodedSignBlockRequest
Sourceimpl TryFrom<SignBlockRequest> for DecodedSignBlockRequest
impl TryFrom<SignBlockRequest> for DecodedSignBlockRequest
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.