#[repr(i32)]pub enum NoteAttachmentKind {
Unspecified = 0,
None = 1,
Word = 2,
Array = 3,
}Expand description
The kind of a note attachment.
Variants
Unspecified = 0
Unspecified attachment kind (default value, should not be used).
None = 1
No attachment.
Word = 2
A single word attachment.
Array = 3
An array attachment.
Implementations
Sourceimpl NoteAttachmentKind
impl NoteAttachmentKind
Sourcepub fn from_i32(value: i32) -> Option<NoteAttachmentKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<NoteAttachmentKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a NoteAttachmentKind, or None if value is not a valid variant.
Sourceimpl NoteAttachmentKind
impl NoteAttachmentKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.