#[repr(i32)]pub enum NoteType {
Unspecified = 0,
Public = 1,
Private = 2,
}Expand description
The type of a note.
Variants
Unspecified = 0
Unspecified note type (default value, should not be used).
Public = 1
Public note - details are visible on-chain.
Private = 2
Private note - details are not visible on-chain.
Implementations
Sourceimpl NoteType
impl NoteType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.