pub struct NoteMetadataHeader {
pub sender: Option<AccountId>,
pub note_type: i32,
pub tag: u32,
pub attachment_kind: i32,
pub attachment_scheme: u32,
}Expand description
Represents the header of a note’s metadata.
Contains the sender, note type, tag and attachment type information, but not the full
attachment data. See miden_protocol::note::NoteMetadataHeader for more info.
Fields
sender: Option<AccountId>The account which sent the note.
note_type: i32The type of the note.
tag: u32A value which can be used by the recipient to identify notes intended for them.
See miden_protocol::note::note_tag for more info.
attachment_kind: i32The kind of the note attachment.
attachment_scheme: u32The scheme identifier of the note attachment.
Implementations
Sourceimpl NoteMetadataHeader
impl NoteMetadataHeader
Sourcepub fn note_type(&self) -> NoteType
pub fn note_type(&self) -> NoteType
Returns the enum value of note_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_note_type(&mut self, value: NoteType)
pub fn set_note_type(&mut self, value: NoteType)
Sets note_type to the provided enum value.
Sourcepub fn attachment_kind(&self) -> NoteAttachmentKind
pub fn attachment_kind(&self) -> NoteAttachmentKind
Returns the enum value of attachment_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_attachment_kind(&mut self, value: NoteAttachmentKind)
pub fn set_attachment_kind(&mut self, value: NoteAttachmentKind)
Sets attachment_kind to the provided enum value.