#[repr(i32)]pub enum WorkerHealthStatus {
Unknown = 0,
Healthy = 1,
Unhealthy = 2,
}Expand description
Health status of a worker.
Variants
Unknown = 0
The worker’s health status is unknown. This value is used when the proxy is not able to determine the health status of the worker. It is only a temporary state and the proxy will eventually determine the health status of the worker.
Healthy = 1
The worker is healthy. This value is used when the worker is able to successfully process requests.
Unhealthy = 2
The worker is unhealthy. This value is used when the worker is not receiving requests or is not able to successfully process requests.
Implementations
Sourceimpl WorkerHealthStatus
impl WorkerHealthStatus
Sourcepub fn from_i32(value: i32) -> Option<WorkerHealthStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<WorkerHealthStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a WorkerHealthStatus, or None if value is not a valid variant.
Sourceimpl WorkerHealthStatus
impl WorkerHealthStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.