Module rpc

Module rpc 

Modules

account_request
Nested message and enum types in AccountRequest.
account_response
Nested message and enum types in AccountResponse.
account_storage_details
Nested message and enum types in AccountStorageDetails.
api_client
Generated client implementations.
api_server
Generated server implementations.
sync_notes_response
Nested message and enum types in SyncNotesResponse.
sync_nullifiers_response
Nested message and enum types in SyncNullifiersResponse.

Structs

AccountRequest
Defines the request for account details.
AccountResponse
Represents the result of getting account proof.
AccountStorageDetails
Account storage details for AccountResponse
AccountVaultDetails
Account vault details for AccountResponse
AccountVaultUpdate
BlockHeaderByNumberRequest
Returns the block header corresponding to the requested block number, as well as the merkle path and current forest which validate the block’s inclusion in the chain.
BlockHeaderByNumberResponse
Represents the result of getting a block header by block number.
BlockProducerStatus
Represents the status of the block producer.
BlockRange
Represents a block range.
BlockSubscriptionRequest
Request to subscribe to the committed block stream.
BlockSubscriptionResponse
A committed block streamed to a replica.
ConsumedNoteRef
Maps a consumed input note’s nullifier to its note ID.
EndpointLimits
Represents the parameter limits for a single endpoint.
GetNetworkNoteStatusResponse
Response containing the lifecycle status and latest execution error for a network note.
MaybeNoteScript
Represents a note script or nothing.
MempoolStats
Statistics about the mempool.
PaginationInfo
Represents pagination information for chunked responses.
ProofSubscriptionRequest
Request to subscribe to the block proof stream.
ProofSubscriptionResponse
A block proof streamed to a replica.
RpcLimits
Represents the query parameter limits for RPC endpoints.
RpcStatus
Represents the status of the node.
StorageMapUpdate
Represents a single storage map update.
SyncAccountStorageMapsRequest
Storage map synchronization request.
SyncAccountStorageMapsResponse
SyncAccountVaultRequest
Account vault synchronization request.
SyncAccountVaultResponse
SyncChainMmrRequest
Chain MMR synchronization request.
SyncChainMmrResponse
Represents the result of syncing chain MMR.
SyncNotesRequest
Note synchronization request.
SyncNotesResponse
Represents the result of syncing notes request.
SyncNullifiersRequest
Returns a list of nullifiers that match the specified prefixes and are recorded in the node.
SyncNullifiersResponse
Represents the result of syncing nullifiers.
SyncTransactionsRequest
Transactions synchronization request.
SyncTransactionsResponse
Represents the result of syncing transactions request.
TransactionRecord
Represents a transaction record.

Enums

FinalityLevel
Finality level we’d like to sync up to.
NetworkNoteStatus
Lifecycle status of a network note within the transaction builder.