pub struct BlockProducerStatus {
pub version: String,
pub status: String,
pub chain_tip: u32,
pub mempool_stats: Option<MempoolStats>,
}Expand description
Represents the status of the block producer.
Fields
version: StringThe block producer’s running version.
status: StringThe block producer’s status.
chain_tip: u32The block producer’s current view of the chain tip height.
This is the height of the latest block that the block producer considers to be part of the canonical chain.
mempool_stats: Option<MempoolStats>Statistics about the mempool.