pub struct SyncChainMmrRequest {
pub block_range: Option<BlockRange>,
}Expand description
Chain MMR synchronization request.
Fields
block_range: Option<BlockRange>Block range from which to synchronize the chain MMR.
The response will contain MMR delta starting after block_range.block_from up to
block_range.block_to or the chain tip (whichever is lower). Set block_from to the last
block already present in the caller’s MMR so the delta begins at the next block.