pub struct SyncNullifiersRequest {
pub block_range: Option<BlockRange>,
pub prefix_len: u32,
pub nullifiers: Vec<u32>,
}Expand description
Returns a list of nullifiers that match the specified prefixes and are recorded in the node.
Fields
block_range: Option<BlockRange>Block number from which the nullifiers are requested (inclusive).
prefix_len: u32Number of bits used for nullifier prefix. Currently the only supported value is 16.
nullifiers: Vec<u32>List of nullifiers to check. Each nullifier is specified by its prefix with length equal
to prefix_len.