pub struct NoteSyncBlock {
pub block_header: Option<BlockHeader>,
pub mmr_path: Option<MerklePath>,
pub notes: Vec<NoteSyncRecord>,
}Expand description
A single block’s worth of note sync data.
Fields
block_header: Option<BlockHeader>Block header of the block containing the matching notes.
mmr_path: Option<MerklePath>Merkle path to verify the block’s inclusion in the MMR.
The proof is valid for an MMR of forest N + 1, where N is the requested
block_range.block_to (or the chain tip if block_to was not specified).
notes: Vec<NoteSyncRecord>List of notes matching the specified criteria in this block, together with the
Merkle paths from block_header.note_root.