Module sequencer

Module sequencer 

Modules

api_client
Generated client implementations.
api_server
Generated server implementations.

Structs

AuthInputs
The store-derived inputs a transaction was authenticated against.
AuthenticatedTransaction
An authenticated transaction.
AuthenticatedTransactionBatch
A proposed batch together with the inputs each of its transactions was authenticated against.
NullifierRecord
A nullifier together with the block in which it was consumed.