pub struct BlockInputs {
pub latest_block_header: Option<BlockHeader>,
pub unauthenticated_note_proofs: Vec<NoteInclusionInBlockProof>,
pub partial_block_chain: Vec<u8>,
pub account_witnesses: Vec<AccountWitness>,
pub nullifier_witnesses: Vec<NullifierWitness>,
}Expand description
Represents the result of getting block inputs.
Fields
latest_block_header: Option<BlockHeader>The latest block header.
unauthenticated_note_proofs: Vec<NoteInclusionInBlockProof>Proof of each requested unauthenticated note’s inclusion in a block, if it existed in the store.
partial_block_chain: Vec<u8>The serialized chain MMR which includes proofs for all blocks referenced by the above note inclusion proofs as well as proofs for inclusion of the requested blocks referenced by the batches in the block.
account_witnesses: Vec<AccountWitness>The state commitments of the requested accounts and their authentication paths.
nullifier_witnesses: Vec<NullifierWitness>The requested nullifiers and their authentication paths.