pub struct BlockInputsRequest {
pub account_ids: Vec<AccountId>,
pub nullifiers: Vec<Digest>,
pub unauthenticated_notes: Vec<Digest>,
pub reference_blocks: Vec<u32>,
}Expand description
Returns data required to prove the next block.
Fields
account_ids: Vec<AccountId>IDs of all accounts updated in the proposed block for which to retrieve account witnesses.
nullifiers: Vec<Digest>Nullifiers of all notes consumed by the block for which to retrieve witnesses.
Due to note erasure it will generally not be possible to know the exact set of nullifiers a block will create, unless we pre-execute note erasure. So in practice, this set of nullifiers will be the set of nullifiers of all proven batches in the block, which is a superset of the nullifiers the block may create.
However, if it is known that a certain note will be erased, it would not be necessary to provide a nullifier witness for it.
unauthenticated_notes: Vec<Digest>Array of note IDs for which to retrieve note inclusion proofs, if they exist in the store.
reference_blocks: Vec<u32>Array of block numbers referenced by all batches in the block.