pub struct UnconsumedNetworkNotesRequest {
pub page_token: Option<u64>,
pub page_size: u64,
pub account_id: Option<AccountId>,
pub block_num: u32,
}Expand description
Returns a paginated list of unconsumed network notes for an account.
Notes created or consumed after the specified block are excluded from the result.
Fields
page_token: Option<u64>This should be null on the first call, and set to the response token until the response token is null, at which point all data has been fetched.
Note that this token is only valid if used with the same parameters.
page_size: u64Number of notes to retrieve per page.
account_id: Option<AccountId>The full account ID to filter notes by.
block_num: u32The block number to filter the returned notes by.
Notes that are created or consumed after this block are excluded from the result.
Implementations
Sourceimpl UnconsumedNetworkNotesRequest
impl UnconsumedNetworkNotesRequest
Sourcepub fn page_token(&self) -> u64
pub fn page_token(&self) -> u64
Returns the value of page_token, or the default value if page_token is unset.