pub struct VaultAssetWitnessesRequest {
pub account_id: Option<AccountId>,
pub vault_keys: Vec<Digest>,
pub block_num: Option<u32>,
}Expand description
Request for vault asset witnesses for a specific account.
Fields
account_id: Option<AccountId>The account ID for which to retrieve vault asset witnesses.
vault_keys: Vec<Digest>Set of asset vault keys to retrieve witnesses for.
block_num: Option<u32>The witnesses returned correspond to the account state at the specified block number.
Optional block number. If not provided, uses the latest state.
The specified block number should be relatively near the chain tip else an error will be returned.
Implementations