Module transaction

Module transaction 

Structs

InputNoteCommitment
Represents a commitment to an input note of a transaction.
NextTransactionEncryptionKey
The next transaction encryption key, announced ahead of a scheduled key rotation.
ProvenTransaction
A proven transaction.
SealedTransactionInputs
Transaction inputs sealed against the validator set’s shared transaction encryption key.
TransactionBatch
A proven batch of transactions.
TransactionEncryptionKey
The shared transaction encryption key, attested by validators.
TransactionHeader
Represents a transaction header.
TransactionId
Represents a transaction ID.
TransactionSummary
Represents a transaction summary.
ValidatorKeyAttestation
A single validator’s attestation of the transaction encryption key.

Enums

IesScheme
IES scheme used for transaction input encryption.