pub struct InputNoteCommitment {
pub nullifier: Option<Digest>,
pub header: Option<NoteHeader>,
}Expand description
Represents a commitment to an input note of a transaction.
For authenticated notes, only the nullifier is present. For unauthenticated notes, the note header is also included.
Fields
nullifier: Option<Digest>The nullifier of the input note.
header: Option<NoteHeader>The note header, present only for unauthenticated input notes.