pub struct ProvenTransaction {
pub transaction: Vec<u8>,
pub transaction_inputs: Option<Vec<u8>>,
}Expand description
A proven transaction.
Note that we currently require full transaction transparency for the network operator. This is a temporary measure while Miden stabilizes its protocol and proof systems. To this end, a transaction submission includes its private inputs which the operator can use to verify the transaction execution and proofs are correct.
This means the transaction is not private wrt the network operator (but it is still private onchain). This requirement will be lifted as Miden matures.
Fields
transaction: Vec<u8>The transaction proof.
Encoded using [miden_protocol::transaction::ProvenTransaction::to_bytes].
transaction_inputs: Option<Vec<u8>>The private inputs used for the transaction proof.
Encoded using [miden_protocol::transaction::TransactionInputs::to_bytes].
Transactions missing this field will be rejected as per the message description.
Implementations
Sourceimpl ProvenTransaction
impl ProvenTransaction
Sourcepub fn transaction_inputs(&self) -> &[u8] ⓘ
pub fn transaction_inputs(&self) -> &[u8] ⓘ
Returns the value of transaction_inputs, or the default value if transaction_inputs is unset.