pub struct TransactionBatch {
pub batch_proof: Vec<u8>,
pub proposed_batch: Option<Vec<u8>>,
pub sealed_transaction_inputs: Vec<SealedTransactionInputs>,
}Expand description
A proven batch of transactions.
Validators require full transaction transparency. Each transaction includes its private inputs. A validator uses these inputs to verify the transaction execution and proof.
The submitter seals these inputs with the shared transaction encryption key of the validator set. Relay nodes cannot read the inputs. Validators reject batches with unsealed inputs.
The validator also requires the proposed batch to verify the batch proof.
Fields
batch_proof: Vec<u8>The batch proof.
Encoded using [miden_protocol::batch::ProvenBatch::to_bytes].
proposed_batch: Option<Vec<u8>>The batch contents of the given proof.
Encoded using [miden_protocol::batch::ProposedBatch::to_bytes].
Batches missing this field will be rejected as per the message description.
sealed_transaction_inputs: Vec<SealedTransactionInputs>The sealed transaction inputs for each transaction in the batch.
Must match the transaction ordering in the batch. Each entry is sealed independently against its own transaction’s id, because the batch is fanned out into one validator submission per transaction.
Batch will be rejected if any transaction’s input is missing as per the method description.
Implementations
Sourceimpl TransactionBatch
impl TransactionBatch
Sourcepub fn proposed_batch(&self) -> &[u8] ⓘ
pub fn proposed_batch(&self) -> &[u8] ⓘ
Returns the value of proposed_batch, or the default value if proposed_batch is unset.