pub struct StoreNtxBuilderClient(/* private fields */);Methods from Deref<Target = NtxBuilderClient<InterceptedService<Channel, Interceptor>>>
Sourcepub async fn get_block_header_by_number(
&mut self,
request: impl IntoRequest<BlockHeaderByNumberRequest>,
) -> Result<Response<BlockHeaderByNumberResponse>, Status>
pub async fn get_block_header_by_number( &mut self, request: impl IntoRequest<BlockHeaderByNumberRequest>, ) -> Result<Response<BlockHeaderByNumberResponse>, Status>
Retrieves block header by given block number. Optionally, it also returns the MMR path and current chain length to authenticate the block’s inclusion.
Sourcepub async fn get_unconsumed_network_notes(
&mut self,
request: impl IntoRequest<UnconsumedNetworkNotesRequest>,
) -> Result<Response<UnconsumedNetworkNotes>, Status>
pub async fn get_unconsumed_network_notes( &mut self, request: impl IntoRequest<UnconsumedNetworkNotesRequest>, ) -> Result<Response<UnconsumedNetworkNotes>, Status>
Returns a paginated list of unconsumed network notes.
Sourcepub async fn get_current_blockchain_data(
&mut self,
request: impl IntoRequest<MaybeBlockNumber>,
) -> Result<Response<CurrentBlockchainData>, Status>
pub async fn get_current_blockchain_data( &mut self, request: impl IntoRequest<MaybeBlockNumber>, ) -> Result<Response<CurrentBlockchainData>, Status>
Returns the block header at the chain tip, as well as the MMR peaks corresponding to this header for executing network transactions. If the block number is not provided, the latest header and peaks will be retrieved.
Sourcepub async fn get_network_account_details_by_id(
&mut self,
request: impl IntoRequest<AccountId>,
) -> Result<Response<MaybeAccountDetails>, Status>
pub async fn get_network_account_details_by_id( &mut self, request: impl IntoRequest<AccountId>, ) -> Result<Response<MaybeAccountDetails>, Status>
Returns the latest state of a network account with the specified account ID.
Sourcepub async fn get_network_account_ids(
&mut self,
request: impl IntoRequest<BlockRange>,
) -> Result<Response<NetworkAccountIdList>, Status>
pub async fn get_network_account_ids( &mut self, request: impl IntoRequest<BlockRange>, ) -> Result<Response<NetworkAccountIdList>, Status>
Returns a list of all network account ids.
Sourcepub async fn get_account(
&mut self,
request: impl IntoRequest<AccountRequest>,
) -> Result<Response<AccountResponse>, Status>
pub async fn get_account( &mut self, request: impl IntoRequest<AccountRequest>, ) -> Result<Response<AccountResponse>, Status>
Returns the latest details of the specified account.
Sourcepub async fn get_note_script_by_root(
&mut self,
request: impl IntoRequest<NoteScriptRoot>,
) -> Result<Response<MaybeNoteScript>, Status>
pub async fn get_note_script_by_root( &mut self, request: impl IntoRequest<NoteScriptRoot>, ) -> Result<Response<MaybeNoteScript>, Status>
Returns the script for a note by its root.
Sourcepub async fn get_vault_asset_witnesses(
&mut self,
request: impl IntoRequest<VaultAssetWitnessesRequest>,
) -> Result<Response<VaultAssetWitnessesResponse>, Status>
pub async fn get_vault_asset_witnesses( &mut self, request: impl IntoRequest<VaultAssetWitnessesRequest>, ) -> Result<Response<VaultAssetWitnessesResponse>, Status>
Returns vault asset witnesses for the specified account.
Sourcepub async fn get_storage_map_witness(
&mut self,
request: impl IntoRequest<StorageMapWitnessRequest>,
) -> Result<Response<StorageMapWitnessResponse>, Status>
pub async fn get_storage_map_witness( &mut self, request: impl IntoRequest<StorageMapWitnessRequest>, ) -> Result<Response<StorageMapWitnessResponse>, Status>
Returns a storage map witness for the specified account and storage map entry.