Re-exports
pub use crate::errors::ConversionResultExt;
Structs
- Grpc
Struct Decoder - Zero-cost struct decoder that captures the parent proto message type.
Traits
- Decode
Bytes Ext - Extension trait on
Deserializabletypes to deserialize from bytes and wrap errors asConversionError. - Grpc
Decode Ext - Extension trait on
prost::Messagetypes to create aGrpcStructDecoderwith the parent type inferred from the value.
Functions
- convert_
digests_ to_ words - Converts a collection of proto primitives to Words, returning a specific error type if conversion fails
- read_
account_ id - read_
account_ ids - Reads account IDs from a request, returning a specific error type if conversion fails
- read_
block_ range - Reads a block range from a request, returning a specific error type if the field is missing
- read_
root - Reads and converts a root field from a request to Word, returning a specific error type if conversion fails