Re-exports
pub use crate::errors::ConversionResultExt;
Structs
- Grpc
Struct Decoder - Zero-cost struct decoder that captures the parent proto message type.
Traits
- Decode
Bytes Ext - Extension trait on
Deserializabletypes to deserialize from bytes and wrap errors asConversionError. - Grpc
Decode Ext - Extension trait on
prost::Messagetypes to create aGrpcStructDecoderwith the parent type inferred from the value.