pub fn read_block_range<E>(
block_range: Option<BlockRange>,
entity: &'static str,
) -> Result<BlockRange, E>where
E: From<ConversionError>,Expand description
Reads a block range from a request, returning a specific error type if the field is missing