Module note
miden_
node_
proto
0.13.7
Module note
Module Items
Structs
Enums
In miden_
node_
proto::
domain
miden_node_proto
::
domain
Module
note
Structs

Single
Target
Network
Note
A newtype that wraps around notes targeting a single network account.
Enums

Network
Note
An enum that wraps around notes used in a network mode.
Network
Note
Error