pub trait Api:
Send
+ Sync
+ 'static {
// Required method
fn get_network_note_status<'life0, 'async_trait>(
&'life0 self,
request: Request<NoteId>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetNetworkNoteStatusResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Generated trait containing gRPC methods that should be implemented for use with ApiServer.
Required Methods
Sourcefn get_network_note_status<'life0, 'async_trait>(
&'life0 self,
request: Request<NoteId>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetNetworkNoteStatusResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_network_note_status<'life0, 'async_trait>(
&'life0 self,
request: Request<NoteId>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetNetworkNoteStatusResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns the current status of a network note.
The status indicates where the note is in its lifecycle: pending execution, processed (consumed by a transaction in the mempool), or discarded after too many failed attempts.
Returns NOT_FOUND if the note ID is not tracked by the network transaction builder.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".