Skip to main contentModule primitives
Source - partial_smt_node
- Nested message and enum types in
PartialSmtNode. - smt_leaf
- Nested message and enum types in
SmtLeaf.
- Asset
- Digest
- A hash digest, the result of a hash function.
- IndexedDigest
- A digest together with its SMT leaf index.
- IndexedSmtLeaf
- A fully materialized SMT leaf together with its index.
- MerklePath
- Represents a Merkle path.
- MmrDelta
- Represents an MMR delta.
- PartialSmt
- A compact representation of a partial SMT containing the nodes needed to reconstruct the
tracked openings.
- PartialSmtNode
- A boundary node needed to reconstruct a partial SMT.
- PartialSmtNodeLevel
- Partial SMT boundary nodes at a single depth.
- SmtLeaf
- A leaf in an SMT, sitting at depth 64. A leaf can contain 0, 1 or multiple leaf entries.
- SmtLeafEntry
- Represents a single SMT leaf entry.
- SmtLeafEntryList
- Multiple leaf entries when hash collisions occur at the same leaf position.
- SmtOpening
- The opening of a leaf in an SMT.
- SparseMerklePath
- A different representation of a Merkle path designed for memory efficiency.