pub struct ApiClient<T> { /* private fields */ }Expand description
RPC API for the RPC component
Implementations
Sourceimpl<T> ApiClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> ApiClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ApiClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn status(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<RpcStatus>, Status>
pub async fn status( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<RpcStatus>, Status>
Returns the status info of the node.
Sourcepub async fn get_limits(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<RpcLimits>, Status>
pub async fn get_limits( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<RpcLimits>, Status>
Returns the query parameter limits configured for RPC methods.
These define the maximum number of each parameter a method will accept. Exceeding the limit will result in the request being rejected and you should instead send multiple smaller requests.
Sourcepub async fn check_nullifiers(
&mut self,
request: impl IntoRequest<NullifierList>,
) -> Result<Response<CheckNullifiersResponse>, Status>
pub async fn check_nullifiers( &mut self, request: impl IntoRequest<NullifierList>, ) -> Result<Response<CheckNullifiersResponse>, Status>
Returns a Sparse Merkle Tree opening proof for each requested nullifier
Each proof demonstrates either:
- Inclusion: Nullifier exists in the tree (note was consumed)
- Non-inclusion: Nullifier does not exist (note was not consumed)
The leaf field indicates the status:
empty_leaf_index: Non-inclusion proof (nullifier not in tree)singleormultiple: Inclusion proof only if the requested nullifier appears as a key.
Verify proofs against the nullifier tree root in the latest block header.
Sourcepub async fn get_account(
&mut self,
request: impl IntoRequest<AccountRequest>,
) -> Result<Response<AccountResponse>, Status>
pub async fn get_account( &mut self, request: impl IntoRequest<AccountRequest>, ) -> Result<Response<AccountResponse>, Status>
Returns the latest details of the specified account.
Sourcepub async fn get_block_by_number(
&mut self,
request: impl IntoRequest<BlockNumber>,
) -> Result<Response<MaybeBlock>, Status>
pub async fn get_block_by_number( &mut self, request: impl IntoRequest<BlockNumber>, ) -> Result<Response<MaybeBlock>, Status>
Returns raw block data for the specified block number.
Sourcepub async fn get_block_header_by_number(
&mut self,
request: impl IntoRequest<BlockHeaderByNumberRequest>,
) -> Result<Response<BlockHeaderByNumberResponse>, Status>
pub async fn get_block_header_by_number( &mut self, request: impl IntoRequest<BlockHeaderByNumberRequest>, ) -> Result<Response<BlockHeaderByNumberResponse>, Status>
Retrieves block header by given block number. Optionally, it also returns the MMR path and current chain length to authenticate the block’s inclusion.
Sourcepub async fn get_notes_by_id(
&mut self,
request: impl IntoRequest<NoteIdList>,
) -> Result<Response<CommittedNoteList>, Status>
pub async fn get_notes_by_id( &mut self, request: impl IntoRequest<NoteIdList>, ) -> Result<Response<CommittedNoteList>, Status>
Returns a list of notes matching the provided note IDs.
Sourcepub async fn get_note_script_by_root(
&mut self,
request: impl IntoRequest<NoteScriptRoot>,
) -> Result<Response<MaybeNoteScript>, Status>
pub async fn get_note_script_by_root( &mut self, request: impl IntoRequest<NoteScriptRoot>, ) -> Result<Response<MaybeNoteScript>, Status>
Returns the script for a note by its root.
Sourcepub async fn submit_proven_transaction(
&mut self,
request: impl IntoRequest<ProvenTransaction>,
) -> Result<Response<BlockNumber>, Status>
pub async fn submit_proven_transaction( &mut self, request: impl IntoRequest<ProvenTransaction>, ) -> Result<Response<BlockNumber>, Status>
Submits proven transaction to the Miden network. Returns the node’s current block height.
Sourcepub async fn submit_proven_batch(
&mut self,
request: impl IntoRequest<ProvenTransactionBatch>,
) -> Result<Response<BlockNumber>, Status>
pub async fn submit_proven_batch( &mut self, request: impl IntoRequest<ProvenTransactionBatch>, ) -> Result<Response<BlockNumber>, Status>
Submits a proven batch of transactions to the Miden network.
The batch may include transactions which were are:
- already in the mempool i.e. previously successfully submitted
- will be submitted to the mempool in the future
- won’t be submitted to the mempool at all
All transactions in the batch but not in the mempool must build on the current mempool state following normal transaction submission rules.
Returns the node’s current block height.
Sourcepub async fn sync_transactions(
&mut self,
request: impl IntoRequest<SyncTransactionsRequest>,
) -> Result<Response<SyncTransactionsResponse>, Status>
pub async fn sync_transactions( &mut self, request: impl IntoRequest<SyncTransactionsRequest>, ) -> Result<Response<SyncTransactionsResponse>, Status>
Returns transactions records for specific accounts within a block range.
Sourcepub async fn sync_notes(
&mut self,
request: impl IntoRequest<SyncNotesRequest>,
) -> Result<Response<SyncNotesResponse>, Status>
pub async fn sync_notes( &mut self, request: impl IntoRequest<SyncNotesRequest>, ) -> Result<Response<SyncNotesResponse>, Status>
Returns info which can be used by the client to sync up to the tip of chain for the notes they are interested in.
Client specifies the note_tags they are interested in, and the block height from which to
search for new for matching notes for. The request will then return the next block containing
any note matching the provided tags.
The response includes each note’s metadata and inclusion proof.
A basic note sync can be implemented by repeatedly requesting the previous response’s block until reaching the tip of the chain.
Sourcepub async fn sync_nullifiers(
&mut self,
request: impl IntoRequest<SyncNullifiersRequest>,
) -> Result<Response<SyncNullifiersResponse>, Status>
pub async fn sync_nullifiers( &mut self, request: impl IntoRequest<SyncNullifiersRequest>, ) -> Result<Response<SyncNullifiersResponse>, Status>
Returns a list of nullifiers that match the specified prefixes and are recorded in the node.
Note that only 16-bit prefixes are supported at this time.
Sourcepub async fn sync_account_vault(
&mut self,
request: impl IntoRequest<SyncAccountVaultRequest>,
) -> Result<Response<SyncAccountVaultResponse>, Status>
pub async fn sync_account_vault( &mut self, request: impl IntoRequest<SyncAccountVaultRequest>, ) -> Result<Response<SyncAccountVaultResponse>, Status>
Returns account vault updates for specified account within a block range.
Sourcepub async fn sync_account_storage_maps(
&mut self,
request: impl IntoRequest<SyncAccountStorageMapsRequest>,
) -> Result<Response<SyncAccountStorageMapsResponse>, Status>
pub async fn sync_account_storage_maps( &mut self, request: impl IntoRequest<SyncAccountStorageMapsRequest>, ) -> Result<Response<SyncAccountStorageMapsResponse>, Status>
Returns storage map updates for specified account and storage slots within a block range.
Sourcepub async fn sync_chain_mmr(
&mut self,
request: impl IntoRequest<SyncChainMmrRequest>,
) -> Result<Response<SyncChainMmrResponse>, Status>
pub async fn sync_chain_mmr( &mut self, request: impl IntoRequest<SyncChainMmrRequest>, ) -> Result<Response<SyncChainMmrResponse>, Status>
Returns MMR delta needed to synchronize the chain MMR within the requested block range.