#[repr(i32)]pub enum NetworkNoteStatus {
Unspecified = 0,
Pending = 1,
NullifierInflight = 2,
Discarded = 3,
NullifierCommitted = 4,
}Expand description
Lifecycle status of a network note within the transaction builder.
Variants
Unspecified = 0
Default / unspecified status.
Pending = 1
The note is awaiting execution or being retried after transient failures.
NullifierInflight = 2
The note has been consumed by a transaction that was sent to the block producer.
Discarded = 3
The note exceeded the maximum retry count and will not be retried.
NullifierCommitted = 4
The note’s consuming transaction has been committed on-chain.
Implementations
Sourceimpl NetworkNoteStatus
impl NetworkNoteStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.