Modules
- api_
client - Generated client implementations.
- api_
server - Generated server implementations.
Structs
- Auth
Inputs - The store-derived inputs a transaction was authenticated against.
- Authenticated
Transaction - An authenticated transaction.
- Authenticated
Transaction Batch - A proposed batch together with the inputs each of its transactions was authenticated against.
- Nullifier
Record - A nullifier together with the block in which it was consumed.