pub struct TransactionBatch {
pub batch_proof: Vec<u8>,
pub proposed_batch: Option<Vec<u8>>,
pub transaction_inputs: Vec<Vec<u8>>,
}Expand description
A proven batch of transactions.
Note that we currently require full transaction transparency for the network operator. This is a temporary measure while Miden stabilizes its protocol and proof systems. To this end, each transaction includes its private inputs which the operator can use to verify the transaction execution and proofs are correct.
This means the transaction is not private wrt the network operator (but it is still private onchain). This requirement will be lifted as Miden matures.
In addition, in order to verify the batch itself, we also require the proposed batch.
Fields
batch_proof: Vec<u8>The batch proof.
Encoded using [miden_protocol::batch::ProvenBatch::to_bytes].
proposed_batch: Option<Vec<u8>>The batch contents of the given proof.
Encoded using [miden_protocol::batch::ProposedBatch::to_bytes].
Batches missing this field will be rejected as per the message description.
transaction_inputs: Vec<Vec<u8>>The transaction inputs for each transaction in the batch.
Must match the transaction ordering in the batch.
Encoded using [miden_protocol::transaction::TransactionInputs::to_bytes].
Batch will be rejected if any transaction’s input is missing as per the method description.
Implementations
Sourceimpl TransactionBatch
impl TransactionBatch
Sourcepub fn proposed_batch(&self) -> &[u8] ⓘ
pub fn proposed_batch(&self) -> &[u8] ⓘ
Returns the value of proposed_batch, or the default value if proposed_batch is unset.